@@ -62,6 +62,7 @@ class AdminInstanceTypes(Helpful, Module):
         :rtype dict
         :return The instance type
         """
+        apply_auto_fill(config)
         payload = validate(config)
 
         query = """
@@ -86,7 +87,7 @@ class AdminInstanceTypes(Helpful, Module):
         :param id: the id of the instance type
 
         :rtype: dict
-        :returns: the dataset
+        :returns: the instance type
         """
         return self.update(id, primehub_load_config(filename=kwargs.get('file', None)))
 
@@ -288,6 +289,13 @@ class AdminInstanceTypes(Helpful, Module):
         return "Manage instance type"
 
 
+def apply_auto_fill(config: dict):
+    if 'cpuLimit' not in config:
+        config['cpuLimit'] = 1
+    if 'memoryLimit' not in config:
+        config['memoryLimit'] = 1
+
+
 def required_field(field):
     return f'{field} is required'
 
