@@ -14,13 +14,13 @@ CUSTOMIZED_COLUMNS: Dict[str, List[tuple]] = {
     'primehub.jobs.list': [
         ('id',),
         ('displayName',),
-        ('schedule',),
+        ('recurrence',),
         ('userName', 'user',),
         ('startTime',),
         ('finishTime',),
         ('phase',),
     ],
-    'primehub.schedules.list': [
+    'primehub.recurring_jobs.list': [
         ('id',),
         ('displayName',),
         ('recurrence',),
@@ -164,7 +164,11 @@ class HumanFriendlyDisplay(Displayable):
         logger.debug('display-many')
 
         # 'module': 'primehub.jobs', 'func': 'list'
-        customized_key = "{}.{}".format(action['module'], action['func'])
+        if action:
+            customized_key = "{}.{}".format(action['module'], action['func'])
+        else:
+            customized_key = "fake-module.fake-function"
+
         if customized_key not in CUSTOMIZED_COLUMNS:
             print(tabulate(value, headers="keys"), file=file)
         else:
